# Qubx

### Next generation of Qube quantitative backtesting framework (QUBX)
```          
   /////\    
  /////  \   
  \\\\\  /   
   \\\\\/    (c) 2024, by M.D.E
```                                          

